<?php

namespace Drupal\whitelabel_entity_print\EventSubscriber;

use Drupal\entity_print\Event\PrintCssAlterEvent;
use Drupal\entity_print\Event\PrintEvents;
use Drupal\whitelabel\WhiteLabelProviderInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Add the white label stylesheets to PDFs generated from white label pages.
 */
class EntityPrintSubscriber implements EventSubscriberInterface {

  /**
   * The white label provider.
   *
   * @var \Drupal\whitelabel\WhiteLabelProviderInterface
   */
  protected $whiteLabelProvider;

  /**
   * Constructs a WhiteLabelProviderInterface object.
   *
   * @param \Drupal\whitelabel\WhiteLabelProviderInterface $white_label_provider
   *   The white label provider.
   */
  public function __construct(WhiteLabelProviderInterface $white_label_provider) {
    $this->whiteLabelProvider = $white_label_provider;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      PrintEvents::CSS_ALTER => 'alterCss',
    ];
  }

  /**
   * Alter the CSS renderable array and add our CSS.
   *
   * @param \Drupal\entity_print\Event\PrintCssAlterEvent $event
   *   The event object.
   */
  public function alterCss(PrintCssAlterEvent $event) {
    if ($whitelabel = $this->whiteLabelProvider->getWhiteLabel()) {
      $event->getBuild()['#attached']['library'][] = 'whitelabel/whitelabel.' . $whitelabel->getToken();
    }
  }

}
